/*
 * This source file is part of ImageViewer
 * For the latest info, see http://thierry.vouriot.free.fr
 * E-mail : vouriott@hotmail.com
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA, or go to
 * http://www.gnu.org/copyleft/lesser.txt.
 *
 */
#include "filetreeexplorer.h"

#include <QHeaderView.h>
#include <QEvent.h>

//=======================================================================
// FileTreeExplorer implementation
//=======================================================================

//-----------------------------------------------------------------------
FileTreeExplorer::FileTreeExplorer(QWidget* pParent)
    : QTreeView(pParent)
{
    m_pDirModel = new QDirModel();

    m_pDirModel->setFilter(QDir::AllEntries | QDir::Hidden);
    m_pDirModel->setSorting(QDir::DirsFirst);
    m_pDirModel->setResolveSymlinks(true);

    this->setModel(m_pDirModel);

    this->header()->hide();

    this->setColumnHidden(1, true);
    this->setColumnHidden(2, true);
    this->setColumnHidden(3, true);

    expandToPath(QDir::currentPath());
}

//-----------------------------------------------------------------------
void FileTreeExplorer::expandToPath(QString strFilePath)
{
    QStringList repList = strFilePath.split(tr("/"), QString::SkipEmptyParts);
    QString strDirToExpand("");

    // we expand each directory
    foreach (QString strRep, repList) {
        strDirToExpand += strRep + "/";
        this->expand(m_pDirModel->index(strDirToExpand));
    }
}

//-----------------------------------------------------------------------
void FileTreeExplorer::mouseDoubleClickEvent(QMouseEvent* pEvent)
{
    QModelIndex index = this->selectionModel()->currentIndex();

    if (!index.isValid()) return;

    if (!m_pDirModel->isDir(index))
        emit doubleClickedOnFile(m_pDirModel->filePath(index));
}




