/*
 * This source file is part of ImageViewer
 * For the latest info, see http://thierry.vouriot.free.fr
 * E-mail : vouriott@hotmail.com
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA, or go to
 * http://www.gnu.org/copyleft/lesser.txt.
 *
 */

#ifndef _FILETREEEXPLORER_H_
#define _FILETREEEXPLORER_H_

#include <QTreeView.h>
#include <QDirModel.h>

//-----------------------------------------------------------------------
/** File explorer.
 */
class FileTreeExplorer : public QTreeView
{
    Q_OBJECT

public:

    /** Constructor.
     *  @param pParent Parent widget.
     */
    FileTreeExplorer(QWidget* pParent = 0);

protected:

    /** Mouse double click event.
     *  @param pEvent Mouse event.
     */
    void mouseDoubleClickEvent(QMouseEvent* pEvent);

signals:

    /** Signal for a double click on a file.
     *  @param strFile Path of the selected file.
     */
    void doubleClickedOnFile(QString strFile);

private:

    /** Expand the treeview to a file path.
     *  @param strFilePath Path of the file.
     */
    void expandToPath(QString strFilePath);

    //! TreeView model
    QDirModel* m_pDirModel;

};

#endif

