/*
 * This source file is part of ImageViewer
 * For the latest info, see http://thierry.vouriot.free.fr
 * E-mail : vouriott@hotmail.com
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place - Suite 330, Boston, MA 02111-1307, USA, or go to
 * http://www.gnu.org/copyleft/lesser.txt.
 *
 */

#ifndef _MAINWINDOW_H_
#define _MAINWINDOW_H_

#include <QMainWindow.h>

#include "filetreeexplorer.h"
#include "imageviewer.h"

class QAction;
class QListWidget;
class QMenu;
class QTextEdit;

//-----------------------------------------------------------------------
/** Main window.
 */
class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    /** Constructor.
     */
    MainWindow();

    /** Open an image.
     *  @param strImgPath Image path.
     */
    void openImage(QString strImgPath)
    {
        m_pImageViewer->openFile(strImgPath);
    }

public slots:

    /** Call when an image has been opened.
     *  @param strImgPath Image path.
     */
    void open(QString strImgPath);

    /** Call when a zoom has been done.
     *  @param dScale Scale factor use to display the image.
     */
    void zoom(double dScale);

    /** Open a "About" dialog.
     */
    void about();

    /** Open the next image in the current directory.
     */
    void nextImage();

    /** Open the previous image in the current directory.
     */
    void prevImage();

    /** Switch between full and normal screen.
     */
    void toggleFullscreen();

private:

    /** Open the next or the previous image in the current directory.
     *  @param bNext If true open the next image else open the previous.
     */
    void changeImage(bool bNext);

    // GUI build functions
    void createActions();
    void createMenus();
    void createToolBars();
    void createStatusBar();

    //! Image viewer
    ImageViewer* m_pImageViewer;
    //! File explorer
    FileTreeExplorer* m_pFileTreeExplorer;

    // GUI variables
    QDockWidget *m_pDock;

    QAction *m_pOpenAct;
    QAction *m_pExitAct;
    QAction *m_pZoomInAct;
    QAction *m_pZoomOutAct;
    QAction *m_pNormalSizeAct;
    QAction *m_pAboutAct;
    QAction *m_pAboutQtAct;
    QAction *m_pNextAct;
    QAction *m_pPrevAct;
    QAction *m_pFullscreenAct;

    QMenu *m_pFileMenu;
    QMenu *m_pViewMenu;
    QMenu *m_pHelpMenu;

    QToolBar *m_pToolBar;
};

#endif
